@@ -10,8 +10,8 @@ def get_env_or_default(key, default):
 
 
 class DateConverter:
-    pattern = r'(.*)年(.*)月(.*)日'
     era2year = {'明治': 1872, '大正': 1912, '昭和': 1925, '平成': 1989, '令和': 2019}
+    pattern = r'((?:明治|大正|昭和|平成|令和).*)年(.*)月(.*)日'
 
     @staticmethod
     def convert(s):
@@ -19,7 +19,7 @@ class DateConverter:
         和暦の日付をdatetimeに変換する
         """
 
-        m = re.fullmatch(DateConverter.pattern, s)
+        m = re.search(DateConverter.pattern, s)
         if not m:
             raise ValueError(f'{s} does not fully match with {DateConverter.pattern}')
         year = DateConverter.convert_year_to_int(m.group(1))
